@@ -7,19 +7,11 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
-/*
- * Revision 2.3  1991/12/30  20:36:46
- * #837: Added AuthLog support for the kaserver
- *
- * Revision 2.2  90/08/29  15:10:50
- * Cleanups.
- * Don't create rxvab security object.
- * 
- * Revision 2.1  90/08/07  19:11:30
- * Start with clean version to sync test and dev trees.
- * */
-
+#include <afsconfig.h>
 #include <afs/param.h>
+
+RCSID("$Header: /cvs/openafs/src/kauth/kaserver.c,v 1.9 2001/08/08 00:03:46 shadow Exp $");
+
 #include <afs/stds.h>
 #include <sys/types.h>
 #ifdef AFS_NT40_ENV
@@ -63,7 +55,7 @@ int MinHours = 0;
 int npwSums = KA_NPWSUMS;               /* needs to be variable sometime */
 
 #include <stdarg.h>
-#if !defined(AFS_NT40_ENV) && !defined(AFS_LINUX20_ENV)
+#if !defined(AFS_NT40_ENV) && !defined(AFS_LINUX20_ENV) && !defined(AFS_DARWIN_ENV) && !defined(AFS_FBSD_ENV)
 #undef vfprintf
 #define vfprintf(stream,fmt,args) _doprnt(fmt,args,stream)
 #endif
@@ -90,7 +82,7 @@ afs_int32 es_Report(char *fmt, ...)
 
 static void initialize_dstats ()
 {
-    bzero (&dynamic_statistics, sizeof(dynamic_statistics));
+    memset(&dynamic_statistics, 0, sizeof(dynamic_statistics));
     dynamic_statistics.start_time = time(0);
     dynamic_statistics.host = myHost;
 }
@@ -110,7 +102,7 @@ static int convert_cell_to_ubik (cellinfo, myHost, serverList)
 	ViceLog(0, ("kaserver: couldn't get address of this host.\n"));
 	exit(1);
     }
-    bcopy(th->h_addr,myHost,sizeof(afs_int32));
+    memcpy(myHost, th->h_addr, sizeof(afs_int32));
 
     for (i=0; i<cellinfo->numServers; i++)
 	if (cellinfo->hostAddr[i].sin_addr.s_addr != *myHost) {
@@ -156,12 +148,13 @@ main (argc, argv)
     int	  servers;
     int	  initFlags;
     int   level;			/* security level for Ubik */
+    afs_int32 i;
+    char  clones[MAXHOSTSPERCELL];
 
     struct rx_service *tservice;
     struct rx_securityClass *sca[1];
     struct rx_securityClass *scm[3];
     
-    extern int afsconf_ClientAuth();
     extern int afsconf_ClientAuthSecure();
     extern int afsconf_ServerAuth();
     extern int afsconf_CheckAuth();
@@ -282,15 +275,21 @@ main (argc, argv)
     OpenLog(AFSDIR_SERVER_KALOG_FILEPATH); 
     SetupLogSignals();
 #endif
+    code = afsconf_GetExtendedCellInfo (KA_conf, cell, AFSCONF_KAUTHSERVICE,
+                                    &cellinfo, &clones);
     if (servers) {
 	if (code = ubik_ParseServerList(argc, argv, &myHost, serverList)) {
 	    com_err(whoami, code, "Couldn't parse server list");
 	    exit(1);
 	}
+        cellinfo.hostAddr[0].sin_addr.s_addr = myHost;
+        for (i=1; i<MAXSERVERS; i++) {
+            if (!serverList[i]) break;
+            cellinfo.hostAddr[i].sin_addr.s_addr = serverList[i];
+        }
+        cellinfo.numServers = i;
     }
     else {
-	code = afsconf_GetCellInfo (KA_conf, cell, AFSCONF_KAUTHSERVICE,
-				    &cellinfo);
 	code = convert_cell_to_ubik (&cellinfo, &myHost, serverList);
 	if (code) goto abort;
 	ViceLog (0, ("Using server list from %s cell database.\n", cell));
@@ -313,8 +312,13 @@ main (argc, argv)
     ubik_CheckRXSecurityRock = (char *)KA_conf;
 
     ubik_nBuffers = 80;
-    code = ubik_ServerInit (myHost, htons(AFSCONF_KAUTHPORT), serverList,
-			    dbpath, &KA_dbase);
+    if (servers)
+        code = ubik_ServerInit (myHost, htons(AFSCONF_KAUTHPORT), serverList,
+                            dbpath, &KA_dbase);
+    else
+        code = ubik_ServerInitByInfo (myHost, htons(AFSCONF_KAUTHPORT), 
+                           &cellinfo, &clones, dbpath, &KA_dbase);
+
     if (code) {
 	com_err(whoami, code, "Ubik init failed");
 	exit(2);
