@@ -19,7 +19,11 @@
  * Return 1 if data available.
  */
 
+#include <afsconfig.h>
 #include <afs/param.h>
+
+RCSID("$Header: /cvs/openafs/src/lwp/waitkey.c,v 1.8 2001/07/19 21:51:49 shadow Exp $");
+
 #include <stdio.h>
 #include <sys/types.h>
 #ifdef AFS_NT40_ENV
@@ -94,6 +98,7 @@ int LWP_WaitForKeystroke(int seconds)
  * Return Value:
  *   n - a whole line has been read.(has n chars)
  *   0 - buf not big enough.
+ *   -1 - line with only EOF
  */
 
 int LWP_GetLine(char *linebuf, int len)
@@ -107,6 +112,10 @@ int LWP_GetLine(char *linebuf, int len)
     { 
       LWP_WaitForKeystroke(-1);
       ch = getch(); 
+      
+      if ((ch == EOF) && (cnt == 0))
+	return -1;
+
       if (ch == '\b') {/* print and throw away a backspace */
 	if (!cnt) /* if we are at the start of the line don't bspace */
 	  continue;
@@ -150,6 +159,7 @@ int LWP_WaitForKeystroke(int seconds)
     struct timeval twait;
     struct timeval *tp = NULL;
 
+#ifndef AFS_DJGPP_ENV
 #ifdef AFS_LINUX20_ENV
     if (stdin->_IO_read_ptr < stdin->_IO_read_end)
 	return 1;
@@ -162,7 +172,10 @@ int LWP_WaitForKeystroke(int seconds)
 	return 1;
 #endif
 #endif
-
+#else /* DJGPP */
+    if (stdin->_cnt > 0)
+	return 1;
+#endif /* DJGPP */
 
     FD_ZERO(&rdfds);
     FD_SET(fileno(stdin), &rdfds);
@@ -187,15 +200,19 @@ int LWP_WaitForKeystroke(int seconds)
  * Return Value:
  *   n - a whole line has been read.(has n chars)
  *   0 - buf not big enough.
+ *   -1 - line with only EOF
  */
 
 int LWP_GetLine(char *linebuf, int len)
 {
   int linelen;
+  char *s;
 
   LWP_WaitForKeystroke(-1);
 
-  fgets(linebuf, len, stdin);
+  s = fgets(linebuf, len, stdin);
+  if (s == NULL) return -1;
+
   linelen = strlen(linebuf);
   if (linebuf[linelen-1] != '\n') /* buffer too small */
     return 0;
