@@ -7,9 +7,11 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
-#ifndef lint
-#endif
+#include <afsconfig.h>
 #include <afs/param.h>
+
+RCSID("$Header: /cvs/openafs/src/ptserver/utils.c,v 1.7 2001/08/08 00:03:54 shadow Exp $");
+
 #include <sys/types.h>
 #include <lock.h>
 #include <ubik.h>
@@ -88,7 +90,7 @@ struct prentry *tentry;
     struct prentry nentry;
 
     if (ntohl(1) != 1) {	/* Need to swap bytes. */
-      bzero (&nentry, sizeof(nentry));	/* make sure reseved fields are zero */
+      memset(&nentry, 0, sizeof(nentry));	/* make sure reseved fields are zero */
       nentry.flags = htonl(tentry->flags);
       nentry.id = htonl(tentry->id);
       nentry.cellid = htonl(tentry->cellid);
@@ -138,7 +140,7 @@ struct prentry *tentry;
     }
     code = ubik_Read(tt, (char *) &nentry, sizeof(struct prentry));
     if (code) return (code);
-    bzero (tentry, sizeof(*tentry));	/* make sure reseved fields are zero */
+    memset(tentry, 0, sizeof(*tentry));	/* make sure reseved fields are zero */
     tentry->flags = ntohl(nentry.flags);
     tentry->id = ntohl(nentry.id);
     tentry->cellid = ntohl(nentry.cellid);
@@ -179,7 +181,7 @@ pr_WriteCoEntry(tt, afd, pos, tentry)
     struct contentry nentry;
 
     if (ntohl(1) != 1) {	/* No need to swap */
-	bzero (&nentry, sizeof(nentry)); /* make reseved fields zero */
+	memset(&nentry, 0, sizeof(nentry)); /* make reseved fields zero */
 	nentry.flags = htonl(tentry->flags);
 	nentry.id = htonl(tentry->id);
 	nentry.cellid = htonl(tentry->cellid);
@@ -209,7 +211,7 @@ struct contentry *tentry;
     }
     code = ubik_Read(tt, (char *) &nentry, sizeof(struct contentry));
     if (code) return (code);
-    bzero (tentry, sizeof(*tentry)); /* make reseved fields zero */
+    memset(tentry, 0, sizeof(*tentry)); /* make reseved fields zero */
     tentry->flags = ntohl(nentry.flags);
     tentry->id = ntohl(nentry.id);
     tentry->cellid = ntohl(nentry.cellid);
@@ -257,7 +259,7 @@ afs_int32 pos;
     register afs_int32 code;
     struct prentry tentry;
 
-    bzero(&tentry,sizeof(tentry));
+    memset(&tentry, 0, sizeof(tentry));
     tentry.next = ntohl(cheader.freePtr);
     tentry.flags |= PRFREE;
     cheader.freePtr = htonl(pos);
@@ -282,13 +284,13 @@ afs_int32 aid;
     i = IDHash(aid);
     entry = ntohl(cheader.idHash[i]);
     if (entry == 0) return entry;
-    bzero(&tentry,sizeof(tentry));
+    memset(&tentry, 0, sizeof(tentry));
     code = pr_ReadEntry(at, 0, entry, &tentry);
     if (code != 0) return 0;
     if (aid == tentry.id) return entry;
     entry = tentry.nextID;
-    while (entry != NULL) {
-	bzero(&tentry,sizeof(tentry));
+    while (entry != 0) {
+	memset(&tentry, 0, sizeof(tentry));
 	code = pr_ReadEntry(at,0,entry,&tentry);
 	if (code != 0) return 0;
 	if (aid == tentry.id) return entry;
@@ -312,13 +314,13 @@ struct prentry *tentryp;
     i = NameHash(aname);
     entry = ntohl(cheader.nameHash[i]);
     if (entry == 0) return entry;
-    bzero(tentryp,sizeof(struct prentry));
+    memset(tentryp, 0, sizeof(struct prentry));
     code = pr_ReadEntry(at, 0, entry, tentryp);
     if (code != 0) return 0;
     if ((strncmp(aname,tentryp->name,PR_MAXNAMELEN)) == 0) return entry;
     entry = tentryp->nextName;
-    while (entry != NULL) {
-	bzero(tentryp, sizeof(struct prentry));
+    while (entry != 0) {
+	memset(tentryp, 0, sizeof(struct prentry));
 	code = pr_ReadEntry(at,0,entry, tentryp);
 	if (code != 0) return 0;
 	if ((strncmp(aname,tentryp->name,PR_MAXNAMELEN)) == 0) return entry;
@@ -410,7 +412,7 @@ afs_int32 *aid;
     return PRSUCCESS;
 }
 
-afs_int32 IDCmp(a,b)
+int IDCmp(a,b)
 afs_int32 *a;
 afs_int32 *b;
 {
@@ -434,21 +436,21 @@ afs_int32 *loc;				/* ??? in case ID hashed twice ??? */
     if ((aid == PRBADID) || (aid == 0)) return PRINCONSISTENT;
     i = IDHash(aid);
     current = ntohl(cheader.idHash[i]);
-    bzero(&tentry,sizeof(tentry));
-    bzero(&bentry,sizeof(bentry));
+    memset(&tentry, 0, sizeof(tentry));
+    memset(&bentry, 0, sizeof(bentry));
     trail = 0;
-    if (current == NULL) return PRSUCCESS; /* already gone */
+    if (current == 0) return PRSUCCESS; /* already gone */
     code = pr_ReadEntry(tt,0,current,&tentry);
     if (code) return PRDBFAIL;
     while (aid != tentry.id) {
 	trail = current;
 	current = tentry.nextID;
-	if (current == NULL) break;
+	if (current == 0) break;
 	code = pr_ReadEntry(tt,0,current,&tentry);
 	if (code) return PRDBFAIL;
     }
-    if (current == NULL) return PRSUCCESS;  /* we didn't find him, so he's already gone */
-    if (trail == NULL) {
+    if (current == 0) return PRSUCCESS;  /* we didn't find him, so he's already gone */
+    if (trail == 0) {
 	/* it's the first entry! */
 	cheader.idHash[i] = htonl(tentry.nextID);
 	code = pr_Write(tt,0,72+HASHSIZE*4+i*4,(char *)&cheader.idHash[i],sizeof(cheader.idHash[i]));
@@ -476,7 +478,7 @@ afs_int32 loc;				/* ??? */
 
     if ((aid == PRBADID) || (aid == 0)) return PRINCONSISTENT;
     i = IDHash(aid);
-    bzero(&tentry,sizeof(tentry));
+    memset(&tentry, 0, sizeof(tentry));
     code = pr_ReadEntry(tt,0,loc,&tentry);
     if (code) return PRDBFAIL;
     tentry.nextID = ntohl(cheader.idHash[i]);
@@ -501,21 +503,21 @@ afs_int32 *loc;
 
     i = NameHash(aname);
     current = ntohl(cheader.nameHash[i]);
-    bzero(&tentry,sizeof(tentry));
-    bzero(&bentry,sizeof(bentry));
+    memset(&tentry, 0, sizeof(tentry));
+    memset(&bentry, 0, sizeof(bentry));
     trail = 0;
-    if (current == NULL) return PRSUCCESS;  /* already gone */
+    if (current == 0) return PRSUCCESS;  /* already gone */
     code = pr_ReadEntry(tt,0,current,&tentry);
     if (code) return PRDBFAIL;
     while (strcmp(aname,tentry.name)) {
 	trail = current;
 	current = tentry.nextName;
-	if (current == NULL) break;
+	if (current == 0) break;
 	code = pr_ReadEntry(tt,0,current,&tentry);
 	if (code) return PRDBFAIL;
     }
-    if (current == NULL) return PRSUCCESS;  /* we didn't find him, already gone */
-    if (trail == NULL) {
+    if (current == 0) return PRSUCCESS;  /* we didn't find him, already gone */
+    if (trail == 0) {
 	/* it's the first entry! */
 	cheader.nameHash[i] = htonl(tentry.nextName);
 	code = pr_Write(tt,0,72+i*4,(char *)&cheader.nameHash[i],sizeof(cheader.nameHash[i]));
@@ -542,7 +544,7 @@ afs_int32 loc;
     struct prentry tentry;
 
     i = NameHash(aname);
-    bzero(&tentry,sizeof(tentry));
+    memset(&tentry, 0, sizeof(tentry));
     code = pr_ReadEntry(tt,0,loc,&tentry);
     if (code) return PRDBFAIL;
     tentry.nextName = ntohl(cheader.nameHash[i]);
@@ -609,7 +611,7 @@ afs_int32 RemoveFromOwnerChain(at,gid,oid)
     le =  &thisEntry;
     lastLoc = 0;
     nptr = thisEntry.owned;
-    while (nptr != NULL) {
+    while (nptr != 0) {
 	if (nptr == lastLoc) te = le;
 	else {
 	    if (&thisEntry == le) te = &thatEntry;
@@ -688,9 +690,9 @@ afs_int32 gid;
 	return PRSUCCESS;
     }
     nptr = ntohl(cheader.orphan);
-    bzero(&bentry,sizeof(bentry));
+    memset(&bentry, 0, sizeof(bentry));
     loc = 0;
-    while (nptr != NULL) {
+    while (nptr != 0) {
 	code = pr_ReadEntry(at,0,nptr,&tentry);
 	if (code != 0) return PRDBFAIL;
 	if (gid == tentry.id) {
@@ -705,7 +707,7 @@ afs_int32 gid;
 	}
 	loc = nptr;
 	nptr = tentry.nextOwned;
-	bcopy(&tentry,&bentry, sizeof(tentry));
+	memcpy(&bentry, &tentry, sizeof(tentry));
     }
     return PRSUCCESS;
 }
@@ -763,7 +765,7 @@ afs_int32 gid;
     if ((gid == 0) || (aid == 0)) return 0;
     loc = FindByID(at,gid);
     if (!loc) return 0;
-    bzero(&tentry,sizeof(tentry));
+    memset(&tentry, 0, sizeof(tentry));
     code = pr_ReadEntry(at, 0, loc,&tentry);
     if (code) return 0;
     if (!(tentry.flags & PRGRP)) return 0;
@@ -774,7 +776,7 @@ afs_int32 gid;
     if (tentry.next) {
 	loc = tentry.next;
 	while (loc) {
-	    bzero(&centry,sizeof(centry));
+	    memset(&centry, 0, sizeof(centry));
 	    code = pr_ReadCoEntry(at,0,loc,&centry);
 	    if (code) return 0;
 	    for (i=0;i<COSIZE;i++) {
