@@ -11,7 +11,11 @@
  * Kerberos-style ticket.  These are the server-only routines. */
 
 
+#include <afsconfig.h>
 #include <afs/param.h>
+
+RCSID("$Header: /cvs/openafs/src/rxkad/rxkad_server.c,v 1.7 2001/08/08 00:04:05 shadow Exp $");
+
 #include <afs/stds.h>
 #include <sys/types.h>
 #include <time.h>
@@ -26,8 +30,6 @@
 #include <afs/afsutil.h>
 #include "private_data.h"
 #define XPRT_RXKAD_SERVER
-#include "../permit_xprt.h"
-
 
 /*
  * This can be set to allow alternate ticket decoding.
@@ -118,12 +120,12 @@ rxkad_NewServerSecurityObject (level, get_key_rock, get_key, user_ok)
     
     size = sizeof(struct rx_securityClass);
     tsc = (struct rx_securityClass *) osi_Alloc (size);
-    bzero (tsc, size);
+    memset(tsc, 0, size);
     tsc->refCount = 1;			/* caller has one reference */
     tsc->ops = &rxkad_server_ops;
     size = sizeof(struct rxkad_sprivate);
     tsp = (struct rxkad_sprivate *) osi_Alloc (size);
-    bzero (tsp, size);
+    memset(tsp, 0, size);
     tsc->privateData = (char *) tsp;
 
     tsp->type |= rxkad_server;		/* so can identify later */
@@ -188,7 +190,7 @@ rxs_return_t rxkad_GetChallenge (aobj, aconn, apacket)
     if (rx_IsUsingPktCksum(aconn)) sconn->cksumSeen = 1;
 
     if (sconn->cksumSeen) {
-	bzero (&c_v2, sizeof(c_v2));
+	memset(&c_v2, 0, sizeof(c_v2));
 	c_v2.version = htonl(RXKAD_CHALLENGE_PROTOCOL_VERSION);
 	c_v2.challengeID = htonl(sconn->challengeID);
 	c_v2.level = htonl((afs_int32)sconn->level);
@@ -196,7 +198,7 @@ rxs_return_t rxkad_GetChallenge (aobj, aconn, apacket)
 	challenge = (char *)&c_v2;
 	challengeSize = sizeof(c_v2);
     } else {
-	bzero (&c_old, sizeof(c_old));
+	memset(&c_old, 0, sizeof(c_old));
 	c_old.challengeID = htonl(sconn->challengeID);
 	c_old.level = htonl((afs_int32)sconn->level);
 	challenge = (char *)&c_old;
@@ -311,7 +313,7 @@ rxs_return_t rxkad_CheckResponse (aobj, aconn, apacket)
 
     code = fc_keysched (&sessionkey, sconn->keysched);
     if (code) return RXKADBADKEY;
-    bcopy (&sessionkey, sconn->ivec, sizeof(sconn->ivec));
+    memcpy(sconn->ivec, &sessionkey, sizeof(sconn->ivec));
 
     if (sconn->cksumSeen) {
 	/* using v2 response */
@@ -320,7 +322,7 @@ rxs_return_t rxkad_CheckResponse (aobj, aconn, apacket)
 	int i;
 	afs_uint32 xor[2];
 
-	bcopy(sconn->ivec, xor, 2*sizeof(afs_int32));
+	memcpy(xor, sconn->ivec, 2*sizeof(afs_int32));
 	fc_cbc_encrypt (&v2r.encrypted, &v2r.encrypted, sizeof(v2r.encrypted),
 			sconn->keysched, xor, DECRYPT);
 	cksum = rxkad_CksumChallengeResponse (&v2r);
@@ -328,7 +330,7 @@ rxs_return_t rxkad_CheckResponse (aobj, aconn, apacket)
 	    return RXKADSEALEDINCON;
 	(void) rxkad_SetupEndpoint (aconn, &endpoint);
 	v2r.encrypted.endpoint.cksum = 0;
-	if (bcmp (&endpoint, &v2r.encrypted.endpoint, sizeof(endpoint)) != 0)
+	if (memcmp (&endpoint, &v2r.encrypted.endpoint, sizeof(endpoint)) != 0)
 	    return RXKADSEALEDINCON;
 	for (i=0; i<RX_MAXCALLS; i++) {
 	    v2r.encrypted.callNumbers[i] = ntohl(v2r.encrypted.callNumbers[i]);
@@ -368,9 +370,9 @@ rxs_return_t rxkad_CheckResponse (aobj, aconn, apacket)
     else {				/* save the info for later retreival */
 	int size = sizeof(struct rxkad_serverinfo);
 	rock = (struct rxkad_serverinfo *) osi_Alloc (size);
-	bzero (rock, size);
+	memset(rock, 0, size);
 	rock->kvno = kvno;
-	bcopy (&client, &rock->client, sizeof(rock->client));
+	memcpy(&rock->client, &client, sizeof(rock->client));
 	sconn->rock = rock;
     }
     return 0;
