@@ -7,7 +7,11 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
+#include <afsconfig.h>
 #include <afs/param.h>
+
+RCSID("$Header: /cvs/openafs/src/ubik/beacon.c,v 1.9 2001/08/08 00:04:12 shadow Exp $");
+
 #include <sys/types.h>
 #ifdef AFS_NT40_ENV
 #include <winsock2.h>
@@ -197,7 +201,7 @@ ubeacon_InitServerListCommon(ame, info, clones, aservers)
         for (i = 0; i < info->numServers; i++) {
             if (i == me) continue;
 	    ts = (struct ubik_server *) malloc(sizeof(struct ubik_server));
-	    bzero(ts, sizeof(struct ubik_server));
+	    memset(ts, 0, sizeof(struct ubik_server));
 	    ts->next = ubik_servers;
 	    ubik_servers = ts;
             ts->addr[0] = info->hostAddr[i].sin_addr.s_addr;
@@ -228,7 +232,7 @@ ubeacon_InitServerListCommon(ame, info, clones, aservers)
         while (servAddr = *aservers++) {
 	    if (i >= MAXSERVERS) return UNHOSTS;	    /* too many hosts */
 	    ts = (struct ubik_server *) malloc(sizeof(struct ubik_server));
-	    bzero(ts, sizeof(struct ubik_server));
+	    memset(ts, 0, sizeof(struct ubik_server));
 	    ts->next = ubik_servers;
 	    ubik_servers = ts;
 	    ts->addr[0] = servAddr;	/* primary address in  net byte order */
@@ -438,9 +442,9 @@ ubeacon_Interact() {
 * Return Values : 0 on success, non-zero on failure
 */
 static verifyInterfaceAddress(ame, info, aservers)
+    afs_uint32 *ame;		/* one of my interface addr in net byte order */
     struct afsconf_cell *info;
     afs_uint32 aservers[]; 	/* list of all possible server addresses */
-    afs_uint32 *ame;		/* one of my interface addr in net byte order */
 {
     afs_uint32	myAddr[UBIK_MAX_INTERFACE_ADDR], *servList, tmpAddr;
     int 	count, index, found, i, j, totalServers, start, end;
