@@ -7,7 +7,11 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
+#include <afsconfig.h>
 #include <afs/param.h>
+
+RCSID("$Header: /cvs/openafs/src/ubik/ubik.c,v 1.7 2001/08/08 00:04:12 shadow Exp $");
+
 #include <sys/types.h>
 #ifdef AFS_NT40_ENV
 #include <winsock2.h>
@@ -20,6 +24,7 @@
 #include <lock.h>
 #include <rx/xdr.h>
 #include <rx/rx.h>
+#include <afs/cellconfig.h>
 
 #define UBIK_INTERNALS
 #include "ubik.h"
@@ -145,7 +150,8 @@ afs_int32 ContactQuorum(aproc, atrans, aflags, aparm0, aparm1, aparm2, aparm3, a
 	    ts->beaconSinceDown = 0;
 	    urecovery_LostServer(); /* tell recovery to try to resend dbase later */
 	} else {            /* success */
-	    okcalls++;	    /* count up how many worked */
+            if (!ts->isClone)
+	        okcalls++;	    /* count up how many worked */
 	    if (aflags & CStampVersion) {
 		ts->version = atrans->dbase->version;
 	    }
@@ -161,12 +167,43 @@ afs_int32 ContactQuorum(aproc, atrans, aflags, aparm0, aparm1, aparm2, aparm3, a
     Note that the host named by myHost should not also be listed in serverList.
 */
 
-int ubik_ServerInit(myHost, myPort, serverList, pathName, dbase)
+int ubik_ServerInitByInfo(myHost, myPort, info, clones, pathName, dbase)
+    struct afsconf_cell *info;  /* in */
+    char clones[];
     afs_int32 myHost;
     short myPort;
+    char *pathName;	/* in */
+    struct ubik_dbase **dbase; /* out */ 
+{
+     afs_int32 code;
+    
+     code = ubik_ServerInitCommon(myHost, myPort, info, clones, 0, pathName, dbase);
+     return code;
+}
+
+int ubik_ServerInit(myHost, myPort, serverList, pathName, dbase)
+    afs_int32 serverList[];    /* in */
+    afs_int32 myHost;
+    short myPort;
+    char *pathName;	/* in */
+    struct ubik_dbase **dbase; /* out */ 
+{
+     afs_int32 code;
+    
+     code = ubik_ServerInitCommon(myHost, myPort, (struct afsconf_cell *)0, 0,
+			serverList, pathName, dbase);
+     return code;
+}
+
+int ubik_ServerInitCommon(myHost, myPort, info, clones, serverList, pathName, dbase)
+    afs_int32 myHost;
+    short myPort;
+    struct afsconf_cell *info;  /* in */
+    char clones[];
     afs_int32 serverList[];    /* in */
     char *pathName;	/* in */
-    struct ubik_dbase **dbase; /* out */ {
+    struct ubik_dbase **dbase; /* out */ 
+{
     register struct ubik_dbase *tdb;
     register afs_int32 code;
     PROCESS junk;
@@ -185,8 +222,8 @@ int ubik_ServerInit(myHost, myPort, serverList, pathName, dbase)
     tdb->pathName = (char *) malloc(strlen(pathName)+1);
     strcpy(tdb->pathName, pathName);
     tdb->activeTrans = (struct ubik_trans *) 0;
-    bzero(&tdb->version, sizeof(struct ubik_version));
-    bzero(&tdb->cachedVersion, sizeof(struct ubik_version));
+    memset(&tdb->version, 0, sizeof(struct ubik_version));
+    memset(&tdb->cachedVersion, 0, sizeof(struct ubik_version));
     Lock_Init(&tdb->versionLock);
     tdb->flags = 0;
     tdb->read = uphys_read;
@@ -245,7 +282,10 @@ int ubik_ServerInit(myHost, myPort, serverList, pathName, dbase)
     if (code) return code;
     code = urecovery_Initialize(tdb);
     if (code) return code;
-    code = ubeacon_InitServerList(myHost, serverList);
+    if (info)
+        code = ubeacon_InitServerListByInfo(myHost, info, clones);
+    else 
+        code = ubeacon_InitServerList(myHost, serverList);
     if (code) return code;
 
     /* now start up async processes */
@@ -359,7 +399,7 @@ int ubik_AbortTrans(transPtr)
     
     dbase = transPtr->dbase;
     DBHOLD(dbase);
-    bzero(&dbase->cachedVersion, sizeof(struct ubik_version));
+    memset(&dbase->cachedVersion, 0, sizeof(struct ubik_version));
     /* see if we're still up-to-date */
     if (!urecovery_AllBetter(dbase, transPtr->flags & TRREADANY)) {
 	udisk_abort(transPtr);
@@ -411,7 +451,7 @@ int ubik_EndTrans(transPtr)
 
     dbase = transPtr->dbase;
     DBHOLD(dbase);
-    bzero(&dbase->cachedVersion, sizeof(struct ubik_version));
+    memset(&dbase->cachedVersion, 0, sizeof(struct ubik_version));
 
     /* give up if no longer current */
     if (!urecovery_AllBetter(dbase, transPtr->flags & TRREADANY)) {
@@ -464,7 +504,7 @@ int ubik_EndTrans(transPtr)
 	    to us, or timeout.  Put safety check in anyway */
 	if (now - realStart > 10 * BIGTIME) {
 	    ubik_stats.escapes++;
-	    printf("ubik escaping from commit wait\n");
+	    ubik_print("ubik escaping from commit wait\n");
 	    break;
 	}
 	for(ts = ubik_servers; ts; ts=ts->next) {
@@ -490,7 +530,7 @@ int ubik_EndTrans(transPtr)
   success:
     udisk_end(transPtr);
     /* update version on successful EndTrans */
-    bcopy(&dbase->version, &dbase->cachedVersion, sizeof(struct ubik_version));
+    memcpy(&dbase->cachedVersion, &dbase->version, sizeof(struct ubik_version));
     
     DBRELE(dbase);
     return 0;
@@ -627,9 +667,7 @@ int ubik_Write(transPtr, buffer, length)
     iovec[transPtr->iovec_info.iovec_wrt_len].position = transPtr->seekPos;
     iovec[transPtr->iovec_info.iovec_wrt_len].length   = length;
     
-    bcopy(buffer, 
-	  &transPtr->iovec_data.iovec_buf_val[transPtr->iovec_data.iovec_buf_len],
-	  length);
+    memcpy(&transPtr->iovec_data.iovec_buf_val[transPtr->iovec_data.iovec_buf_len], buffer, length);
 
     transPtr->iovec_info.iovec_wrt_len++;
     transPtr->iovec_data.iovec_buf_len += length;
@@ -788,9 +826,9 @@ int panic(a, b, c, d)
     char *a, *b, *c, *d;
 {
     ubik_print("Ubik PANIC: ");
-    printf(a, b, c, d);
+    ubik_print(a, b, c, d);
     abort();
-    printf("BACK FROM ABORT\n");    /* shouldn't come back */
+    ubik_print("BACK FROM ABORT\n");    /* shouldn't come back */
     exit(1);	                    /* never know, though  */
 }
 
